@@ -112,7 +112,7 @@ class DeferredPriorityQueue(object):
                 if existing.valid:
                     raise RuntimeError("Object %r already in queue." % (obj,))
             if count is None:
-                count = next(self._counter)
+                count = self._counter.next()
             task = _Task(obj, priority, count)
             self._objFinder[obj] = task
             heappush(self._pending, task)
