@@ -77,8 +77,9 @@ class ResizableDispatchQueue(object):
             raise QueueStopped()
         else:
             job = Job(jobarg, priority)
+            d = job.watch().addBoth(self._jobDone, job)
             self._queue.put(job, priority)
-            return job.watch().addBoth(self._jobDone, job)
+            return d
 
     def _jobDone(self, result, job):
         """
@@ -266,14 +267,13 @@ class ResizableDispatchQueue(object):
         if job is not self._NOOP:
             self._underway.add(job)
             job.launch(self._func)
-            # Return the first waiting Deferred for the job, if any. Our
-            # self._coop (a task.Cooperator) will wait for it. If there is
-            # no waiting Deferred, the job has already finished (probably
-            # synchronously) and there's nothing to wait for.
+            # Return the first waiting Deferred for the job, if any.
+            # Otherwise return a new Deferred for the job. Our self._coop
+            # (a task.Cooperator) will wait for the Deferred result.
             try:
                 return job.waiting[0]
             except IndexError:
-                pass
+                return job.watch()
 
     def getWidth(self):
         """
