@@ -117,6 +117,10 @@ class TestSimple(unittest.TestCase):
     Simple tests of the ResizableDispatchQueue class.
     """
     def testUnstarted(self):
+        """
+        Check basic facts about a fresh instance of a
+        ResizableDispatchQueue.
+        """
         dq = ResizableDispatchQueue(None)
         self.assertEqual(dq.pending(), [])
         self.assertEqual(dq.underway(), set())
@@ -126,16 +130,31 @@ class TestSimple(unittest.TestCase):
         return dq.stop()
 
     def testNumericStartWidth(self):
+        """
+        Check that passing a numeric width to the constructor works as
+        expected.
+        """
         dq = ResizableDispatchQueue(None, 10)
         self.assertEqual(dq.width, 10)
 
     def testNegativeStartWidth(self):
+        """
+        Passing a negative width to the constructor should raise C{ValueError}.
+        """
         self.assertRaises(ValueError, ResizableDispatchQueue, None, -1)
 
     def testNonNumericStartWidth(self):
+        """
+        Passing a non-numeric width to the constructor should raise
+        C{ValueError}.
+        """
         self.assertRaises(ValueError, ResizableDispatchQueue, None, 'hi')
 
-    def testStartedSize(self):
+    def testSimplePending(self):
+        """
+        Putting 3 jobs onto a queue with zero width should result in a
+        number of pending jobs of 3.
+        """
         dq = ResizableDispatchQueue(None)
         map(dq.put, range(3))
         self.assertEqual((0, 3), dq.size())
@@ -150,8 +169,6 @@ class TestSimple(unittest.TestCase):
         dq.width = 0
         dq.put('aaa')
         dq.put('bbb')
-        # import time
-        # time.sleep(0.10)
         self.assertEqual((0, 2), dq.size())
         return dq.stop()
 
@@ -623,3 +640,15 @@ class TestTiming(unittest.TestCase):
         yield task.deferLater(reactor, 0.05, self._testSize, dq, (0, 2))
         remaining = yield dq.stop()
         self.assertEqual(['aaa', 'bbb'], [job.jobarg for job in remaining])
+
+    @defer.inlineCallbacks
+    def testPuttingMoreThanWidthOnlyDispatchesWidth(self):
+        """
+        Make sure that if we put 5 things onto a queue whose width is 3
+        that shortly thereafter there are 3 jobs underway and 2 pending.
+        """
+        dq = ResizableDispatchQueue(self.slow, 3)
+        for value in range(5):
+            reactor.callLater(0.01, dq.put, value)
+        yield task.deferLater(reactor, 0.1, self._testSize, dq, (3, 2))
+        remaining = yield dq.stop()
